/// <reference types="react" />
import { MaterialReactTableProps, MRT_TableInstance, MRT_Row } from 'material-react-table';
import React from 'react';
import { SvgIconTypeMap, ExtendButtonBase, ButtonTypeMap } from '@mui/material';
import { OverridableComponent } from '@mui/material/OverridableComponent';
import { ThemeOptions } from '@mui/material/styles/createTheme';
import { ReportApi, IRequestOptions, IReportListItemResponse } from 'peekdata-datagateway-api-sdk';
import { SvgIconTypeMap as SvgIconTypeMap$1 } from '@mui/material/SvgIcon';

interface TableProps<TData extends Record<string, any>> extends MaterialReactTableProps<TData> {
}

declare const Table: <Column extends Record<string, any>>({ columns, data, ...props }: TableProps<Column>) => JSX.Element;

interface ReportsTableProps {
    reportApi: ReportApi;
    userId?: string;
    requestOptions?: IRequestOptions;
    tableProps?: MaterialReactTableProps<IReportListItemResponse>;
    theme?: ThemeOptions;
    enableTitleEditing?: boolean;
    EditIcon?: OverridableComponent<SvgIconTypeMap<{}, "svg">> & {
        muiName: string;
    };
    DeleteIcon?: OverridableComponent<SvgIconTypeMap<{}, "svg">> & {
        muiName: string;
    };
    AddButton?: ExtendButtonBase<ButtonTypeMap<{}, "button">>;
    onAddReportClick?: (table: MRT_TableInstance<IReportListItemResponse>) => void;
    onEditReportClick?: (report: IReportListItemResponse, row: MRT_Row<IReportListItemResponse>, table: MRT_TableInstance<IReportListItemResponse>) => void;
    onDeleteReportClick?: (report: IReportListItemResponse, row: MRT_Row<IReportListItemResponse>, table: MRT_TableInstance<IReportListItemResponse>) => void;
}

declare const ReportsTable: React.FC<ReportsTableProps>;

interface TableActionButtonProps<TData extends Record<string, any>> {
    tooltipPlacement?: "top" | "right" | "bottom" | "left" | "bottom-end" | "bottom-start" | "left-end" | "left-start" | "right-end" | "right-start" | "top-end" | "top-start";
    showTooltip?: boolean;
    showTooltipArrow?: boolean;
    tooltipText?: string;
    Icon: OverridableComponent<SvgIconTypeMap$1<{}, "svg">> & {
        muiName: string;
    };
    onClick: () => void;
}

declare const TableActionButton: <TData extends Record<string, any>>(props: TableActionButtonProps<TData>) => JSX.Element;

export { ReportsTable, Table, TableActionButton };
